************
Introduction
************

This little convenience package extracts the cython based `Navarro and Fuss <https://psycnet.apa.org/record/2009-11068-003>`_ likelihoods from the `HDDM <https://hddm.readthedocs.io/en/latest/>`_ package for fitting hierarchical versions of the `Drift Diffusion Model <https://www.ncbi.nlm.nih.gov/pmc/articles/PMC2474742>`_ .












The code of this repo is essentially taken from the `HDDM <https://hddm.readthedocs.io/en/latest/>`_ package. 

The Copyright information for the original package is:

:Author: Thomas V. Wiecki, Imri Sofer, Mads L. Pedersen, Alexander Fengler, Lakshmi Govindarajan, Krishn Bera, Michael J. Frank
:Contact: thomas.wiecki@gmail.com, imri_sofer@brown.edu, madslupe@gmail.com, alexander_fengler@brown.edu, krishn_bera@brown.edu, michael_frank@brown.edu
:Web site: https://hddm.readthedocs.io
:Github: http://github.com/hddm-devs/hddm
:Mailing list: https://groups.google.com/group/hddm-users/
:Copyright: This document has been placed in the public domain.
:License: HDDM is released under the BSD 2 license.
:Version: 0.9.7
